# Ten Drops

![GitHub License](https://img.shields.io/github/license/chyok/ten-drops)
![PyPI - Version](https://img.shields.io/pypi/v/ten-drops)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/ten-drops)

A ten drops game written in pygame-ce.  
Click on these water droplets to make them explode until the screen is cleared.

The inspiration and assets all come from the Flash game "Splash Back".

![example](https://github.com/chyok/ten-drops/assets/32629225/b8409169-dd31-4912-a91e-5fed288a833c)

## Installation

### use pip

```commandline
pip install ten-drops

ten-drops  // start the game 
```

### binary file

Binary files for Windows that can be directly executed to play the game.  
For other systems, the Python source code can be directly executed.

| Platform | Download Link                                           | 
|----------|---------------------------------------------------------|
| Windows  | [Download](https://github.com/chyok/ten-drops/releases) |

## License

This project is licensed under the [MIT License](LICENSE).

